/* webmedia-now-playing.c generated by valac 0.38.8, the Vala compiler
 * generated from webmedia-now-playing.vala, do not modify */

/*
 Copyright (C) 2014 James Axl <axlrose112@gmail.com>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 See the file COPYING for the full license text.
*/

#include <glib.h>
#include <glib-object.h>
#include "midori/midori-extension.h"
#include "webmedia-now-playing.h"
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include "midori/midori-app.h"
#include "midori/midori-browser.h"
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <stdio.h>


#define WEB_MEDIA_TYPE_MANAGER (web_media_manager_get_type ())
#define WEB_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WEB_MEDIA_TYPE_MANAGER, WebMediaManager))
#define WEB_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WEB_MEDIA_TYPE_MANAGER, WebMediaManagerClass))
#define WEB_MEDIA_IS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WEB_MEDIA_TYPE_MANAGER))
#define WEB_MEDIA_IS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WEB_MEDIA_TYPE_MANAGER))
#define WEB_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WEB_MEDIA_TYPE_MANAGER, WebMediaManagerClass))

typedef struct _WebMediaManager WebMediaManager;
typedef struct _WebMediaManagerClass WebMediaManagerClass;
typedef struct _WebMediaManagerPrivate WebMediaManagerPrivate;
enum  {
	WEB_MEDIA_MANAGER_0_PROPERTY,
	WEB_MEDIA_MANAGER_NUM_PROPERTIES
};
static GParamSpec* web_media_manager_properties[WEB_MEDIA_MANAGER_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
enum  {
	WEB_MEDIA_DBUS_SERVICE_0_PROPERTY,
	WEB_MEDIA_DBUS_SERVICE_VIDEO_TITLE_PROPERTY,
	WEB_MEDIA_DBUS_SERVICE_VIDEO_URI_PROPERTY,
	WEB_MEDIA_DBUS_SERVICE_NUM_PROPERTIES
};
static GParamSpec* web_media_dbus_service_properties[WEB_MEDIA_DBUS_SERVICE_NUM_PROPERTIES];
enum  {
	WEB_MEDIA_WEB_MEDIA_NOTIFY_0_PROPERTY,
	WEB_MEDIA_WEB_MEDIA_NOTIFY_APP_PROPERTY,
	WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_VIDEO_TITLE_PROPERTY,
	WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_MEDIA_PROPERTY,
	WEB_MEDIA_WEB_MEDIA_NOTIFY_NUM_PROPERTIES
};
static GParamSpec* web_media_web_media_notify_properties[WEB_MEDIA_WEB_MEDIA_NOTIFY_NUM_PROPERTIES];

struct _WebMediaManager {
	MidoriExtension parent_instance;
	WebMediaManagerPrivate * priv;
};

struct _WebMediaManagerClass {
	MidoriExtensionClass parent_class;
};

struct _WebMediaManagerPrivate {
	WebMediaDbusService* _dbus_service;
	WebMediaWebMediaNotify* _web_media_notify;
	gchar* _web_media_uri;
	gchar* _web_media_title;
};

struct _WebMediaDbusServicePrivate {
	guint _service;
	guint _own_name_id;
	GDBusConnection* _dbus_service_connection;
	gchar* _video_title;
	gchar* _video_uri;
};

struct _WebMediaWebMediaNotifyPrivate {
	MidoriApp* _app;
	gchar* _notify_video_title;
	gchar* _notify_media;
};


static gpointer web_media_manager_parent_class = NULL;
static gpointer web_media_dbus_service_parent_class = NULL;
static gpointer web_media_web_media_notify_parent_class = NULL;

GType web_media_manager_get_type (void) G_GNUC_CONST;
#define WEB_MEDIA_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), WEB_MEDIA_TYPE_MANAGER, WebMediaManagerPrivate))
WebMediaManager* web_media_manager_new (void);
WebMediaManager* web_media_manager_construct (GType object_type);
static void web_media_manager_activated (WebMediaManager* self, MidoriApp* app);
static void _web_media_manager_activated_midori_extension_activate (MidoriExtension* _sender, MidoriApp* app, gpointer self);
static void web_media_manager_deactivated (WebMediaManager* self);
static void _web_media_manager_deactivated_midori_extension_deactivate (MidoriExtension* _sender, gpointer self);
static void web_media_manager_youtube_validation (WebMediaManager* self, GObject* object, GParamSpec* pspec);
static const gchar* web_media_manager_get_web_media_uri (WebMediaManager* self);
static const gchar* web_media_manager_get_web_media_title (WebMediaManager* self);
static void web_media_manager_set_web_media_uri (WebMediaManager* self, const gchar* value);
static void web_media_manager_set_web_media_title (WebMediaManager* self, const gchar* value);
static WebMediaDbusService* web_media_manager_get_dbus_service (WebMediaManager* self);
static WebMediaWebMediaNotify* web_media_manager_get_web_media_notify (WebMediaManager* self);
static void web_media_manager_browser_added (WebMediaManager* self, MidoriBrowser* browser);
static void _web_media_manager_youtube_validation_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void web_media_manager_set_dbus_service (WebMediaManager* self, WebMediaDbusService* value);
static void web_media_manager_set_web_media_notify (WebMediaManager* self, WebMediaWebMediaNotify* value);
static void _web_media_manager_browser_added_midori_app_add_browser (MidoriApp* _sender, MidoriBrowser* browser, gpointer self);
static void web_media_manager_finalize (GObject * obj);
static void _vala_web_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_web_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define WEB_MEDIA_DBUS_SERVICE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), WEB_MEDIA_TYPE_DBUS_SERVICE, WebMediaDbusServicePrivate))
static void web_media_dbus_service_on_bus_aquired (WebMediaDbusService* self, GDBusConnection* connection);
static void _web_media_dbus_service_on_bus_aquired_gbus_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self);
static void __lambda4_ (WebMediaDbusService* self);
static void ___lambda4__gbus_name_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self);
static void __lambda5_ (WebMediaDbusService* self);
static void ___lambda5__gbus_name_lost_callback (GDBusConnection* connection, const gchar* name, gpointer self);
static void web_media_dbus_service_set_own_name_id (WebMediaDbusService* self, guint value);
static guint web_media_dbus_service_get_own_name_id (WebMediaDbusService* self);
static GDBusConnection* web_media_dbus_service_get_dbus_service_connection (WebMediaDbusService* self);
static guint web_media_dbus_service_get_service (WebMediaDbusService* self);
static void web_media_dbus_service_set_dbus_service_connection (WebMediaDbusService* self, GDBusConnection* value);
static void web_media_dbus_service_set_service (WebMediaDbusService* self, guint value);
static void web_media_dbus_service_finalize (GObject * obj);
static void _vala_web_media_dbus_service_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_web_media_dbus_service_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _dbus_web_media_dbus_service_dbus_empty (WebMediaDbusService* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_web_media_dbus_service_register_service (WebMediaDbusService* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void _dbus_web_media_dbus_service_unregister_service (WebMediaDbusService* self, GVariant* _parameters_, GDBusMethodInvocation* invocation);
static void web_media_dbus_service_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* web_media_dbus_service_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static GVariant* _dbus_web_media_dbus_service_get_video_title (WebMediaDbusService* self);
static GVariant* _dbus_web_media_dbus_service_get_video_uri (WebMediaDbusService* self);
static gboolean web_media_dbus_service_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_web_media_dbus_service_set_video_title (WebMediaDbusService* self, GVariant* _value);
static void _dbus_web_media_dbus_service_set_video_uri (WebMediaDbusService* self, GVariant* _value);
static void _web_media_dbus_service_unregister_object (gpointer user_data);
#define WEB_MEDIA_WEB_MEDIA_NOTIFY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), WEB_MEDIA_TYPE_WEB_MEDIA_NOTIFY, WebMediaWebMediaNotifyPrivate))
static void web_media_web_media_notify_finalize (GObject * obj);
static void _vala_web_media_web_media_notify_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_web_media_web_media_notify_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const GDBusArgInfo * const _web_media_dbus_service_dbus_arg_info_dbus_empty_in[] = {NULL};
static const GDBusArgInfo * const _web_media_dbus_service_dbus_arg_info_dbus_empty_out[] = {NULL};
static const GDBusMethodInfo _web_media_dbus_service_dbus_method_info_dbus_empty = {-1, "DbusEmpty", (GDBusArgInfo **) (&_web_media_dbus_service_dbus_arg_info_dbus_empty_in), (GDBusArgInfo **) (&_web_media_dbus_service_dbus_arg_info_dbus_empty_out)};
static const GDBusArgInfo * const _web_media_dbus_service_dbus_arg_info_register_service_in[] = {NULL};
static const GDBusArgInfo * const _web_media_dbus_service_dbus_arg_info_register_service_out[] = {NULL};
static const GDBusMethodInfo _web_media_dbus_service_dbus_method_info_register_service = {-1, "RegisterService", (GDBusArgInfo **) (&_web_media_dbus_service_dbus_arg_info_register_service_in), (GDBusArgInfo **) (&_web_media_dbus_service_dbus_arg_info_register_service_out)};
static const GDBusArgInfo * const _web_media_dbus_service_dbus_arg_info_unregister_service_in[] = {NULL};
static const GDBusArgInfo * const _web_media_dbus_service_dbus_arg_info_unregister_service_out[] = {NULL};
static const GDBusMethodInfo _web_media_dbus_service_dbus_method_info_unregister_service = {-1, "UnregisterService", (GDBusArgInfo **) (&_web_media_dbus_service_dbus_arg_info_unregister_service_in), (GDBusArgInfo **) (&_web_media_dbus_service_dbus_arg_info_unregister_service_out)};
static const GDBusMethodInfo * const _web_media_dbus_service_dbus_method_info[] = {&_web_media_dbus_service_dbus_method_info_dbus_empty, &_web_media_dbus_service_dbus_method_info_register_service, &_web_media_dbus_service_dbus_method_info_unregister_service, NULL};
static const GDBusSignalInfo * const _web_media_dbus_service_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _web_media_dbus_service_dbus_property_info_video_title = {-1, "VideoTitle", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE};
static const GDBusPropertyInfo _web_media_dbus_service_dbus_property_info_video_uri = {-1, "VideoUri", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE};
static const GDBusPropertyInfo * const _web_media_dbus_service_dbus_property_info[] = {&_web_media_dbus_service_dbus_property_info_video_title, &_web_media_dbus_service_dbus_property_info_video_uri, NULL};
static const GDBusInterfaceInfo _web_media_dbus_service_dbus_interface_info = {-1, "org.midori.mediaHerald", (GDBusMethodInfo **) (&_web_media_dbus_service_dbus_method_info), (GDBusSignalInfo **) (&_web_media_dbus_service_dbus_signal_info), (GDBusPropertyInfo **) (&_web_media_dbus_service_dbus_property_info)};
static const GDBusInterfaceVTable _web_media_dbus_service_dbus_interface_vtable = {web_media_dbus_service_dbus_interface_method_call, web_media_dbus_service_dbus_interface_get_property, web_media_dbus_service_dbus_interface_set_property};

static void _web_media_manager_activated_midori_extension_activate (MidoriExtension* _sender, MidoriApp* app, gpointer self) {
#line 24 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_activated ((WebMediaManager*) self, app);
#line 176 "webmedia-now-playing.c"
}


static void _web_media_manager_deactivated_midori_extension_deactivate (MidoriExtension* _sender, gpointer self) {
#line 25 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_deactivated ((WebMediaManager*) self);
#line 183 "webmedia-now-playing.c"
}


WebMediaManager* web_media_manager_construct (GType object_type) {
	WebMediaManager * self = NULL;
#line 20 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self = (WebMediaManager*) g_object_new (object_type, "name", _ ("Webmedia now-playing"), "description", _ ("Share 'youtube, vimeo, dailymotion, coub and zippcast' that you are pl" \
"aying in Midori using org.midori.mediaHerald"), "version", "0.1" MIDORI_VERSION_SUFFIX, "authors", "James Axl <axlrose112@gmail.com>", NULL);
#line 24 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_signal_connect_object ((MidoriExtension*) self, "activate", (GCallback) _web_media_manager_activated_midori_extension_activate, self, 0);
#line 25 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_signal_connect_object ((MidoriExtension*) self, "deactivate", (GCallback) _web_media_manager_deactivated_midori_extension_deactivate, self, 0);
#line 19 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return self;
#line 197 "webmedia-now-playing.c"
}


WebMediaManager* web_media_manager_new (void) {
#line 19 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return web_media_manager_construct (WEB_MEDIA_TYPE_MANAGER);
#line 204 "webmedia-now-playing.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return self ? g_object_ref (self) : NULL;
#line 211 "webmedia-now-playing.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1411 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1411 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 231 "webmedia-now-playing.c"
}


static void web_media_manager_youtube_validation (WebMediaManager* self, GObject* object, GParamSpec* pspec) {
	MidoriBrowser* browser = NULL;
	GObject* _tmp0_;
	MidoriBrowser* _tmp1_;
	gboolean _tmp2_ = FALSE;
	MidoriBrowser* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	MidoriBrowser* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gboolean _tmp10_;
	const gchar* _tmp19_;
	MidoriBrowser* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	gboolean _tmp24_;
	const gchar* _tmp25_;
	MidoriBrowser* _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	MidoriBrowser* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	MidoriBrowser* _tmp33_;
	const gchar* _tmp34_;
	const gchar* _tmp35_;
	GError * _inner_error_ = NULL;
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (object != NULL);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (pspec != NULL);
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = object;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, MIDORI_TYPE_BROWSER) ? ((MidoriBrowser*) _tmp0_) : NULL);
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	browser = _tmp1_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp3_ = browser;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_get (_tmp3_, "uri", &_tmp4_, NULL);
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp5_ = _tmp4_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp6_ = _tmp5_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp7_ = browser;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp8_ = gtk_window_get_title ((GtkWindow*) _tmp7_);
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp9_ = _tmp8_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp10_ = g_strcmp0 (_tmp6_, _tmp9_) == 0;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (_tmp6_);
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (_tmp10_) {
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp2_ = TRUE;
#line 300 "webmedia-now-playing.c"
	} else {
		MidoriBrowser* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		MidoriBrowser* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
		gboolean _tmp18_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp11_ = browser;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_object_get (_tmp11_, "uri", &_tmp12_, NULL);
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp13_ = _tmp12_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp14_ = _tmp13_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp15_ = browser;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp16_ = gtk_window_get_title ((GtkWindow*) _tmp15_);
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp17_ = _tmp16_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp18_ = string_contains (_tmp14_, _tmp17_);
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp2_ = _tmp18_;
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_free0 (_tmp14_);
#line 330 "webmedia-now-playing.c"
	}
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (_tmp2_) {
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_object_unref0 (browser);
#line 30 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		return;
#line 338 "webmedia-now-playing.c"
	}
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp19_ = self->priv->_web_media_uri;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp20_ = browser;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_get (_tmp20_, "uri", &_tmp21_, NULL);
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp22_ = _tmp21_;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp23_ = _tmp22_;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp24_ = g_strcmp0 (_tmp19_, _tmp23_) == 0;
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (_tmp23_);
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (_tmp24_) {
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_object_unref0 (browser);
#line 31 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		return;
#line 360 "webmedia-now-playing.c"
	}
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp25_ = self->priv->_web_media_title;
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp26_ = browser;
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp27_ = gtk_window_get_title ((GtkWindow*) _tmp26_);
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp28_ = _tmp27_;
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (g_strcmp0 (_tmp25_, _tmp28_) == 0) {
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_object_unref0 (browser);
#line 32 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		return;
#line 376 "webmedia-now-playing.c"
	}
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp29_ = browser;
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_get (_tmp29_, "uri", &_tmp30_, NULL);
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp31_ = _tmp30_;
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp32_ = _tmp31_;
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_set_web_media_uri (self, _tmp32_);
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (_tmp32_);
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp33_ = browser;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp34_ = gtk_window_get_title ((GtkWindow*) _tmp33_);
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp35_ = _tmp34_;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_set_web_media_title (self, _tmp35_);
#line 398 "webmedia-now-playing.c"
	{
		GRegex* youtube = NULL;
		GRegex* _tmp36_;
		GRegex* vimeo = NULL;
		GRegex* _tmp37_;
		GRegex* dailymotion = NULL;
		GRegex* _tmp38_;
		GRegex* coub = NULL;
		GRegex* _tmp39_;
		GRegex* zippcast = NULL;
		GRegex* _tmp40_;
		gchar* website = NULL;
		gboolean _tmp41_ = FALSE;
		gboolean _tmp42_ = FALSE;
		gboolean _tmp43_ = FALSE;
		gboolean _tmp44_ = FALSE;
		const gchar* _tmp45_;
		gboolean _tmp46_;
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp36_ = g_regex_new ("(http|https)://www.youtube.com/watch\\?v=[&=_\\-A-Za-z0-9.\\|]+", 0, 0, &_inner_error_);
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		youtube = _tmp36_;
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 425 "webmedia-now-playing.c"
				goto __catch0_g_regex_error;
			}
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_object_unref0 (browser);
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_clear_error (&_inner_error_);
#line 36 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			return;
#line 436 "webmedia-now-playing.c"
		}
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp37_ = g_regex_new ("(http|https)://vimeo.com/[0-9]+", 0, 0, &_inner_error_);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		vimeo = _tmp37_;
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 448 "webmedia-now-playing.c"
				goto __catch0_g_regex_error;
			}
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_object_unref0 (browser);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_clear_error (&_inner_error_);
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			return;
#line 461 "webmedia-now-playing.c"
		}
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp38_ = g_regex_new ("(http|https)://www.dailymotion.com/video/[_\\-A-Za-z0-9]+", 0, 0, &_inner_error_);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		dailymotion = _tmp38_;
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (vimeo);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 475 "webmedia-now-playing.c"
				goto __catch0_g_regex_error;
			}
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (vimeo);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_object_unref0 (browser);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_clear_error (&_inner_error_);
#line 38 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			return;
#line 490 "webmedia-now-playing.c"
		}
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp39_ = g_regex_new ("(http|https)://coub.com/view/[&=_\\-A-Za-z0-9.\\|]+", 0, 0, &_inner_error_);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		coub = _tmp39_;
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (dailymotion);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (vimeo);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 506 "webmedia-now-playing.c"
				goto __catch0_g_regex_error;
			}
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (dailymotion);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (vimeo);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_object_unref0 (browser);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_clear_error (&_inner_error_);
#line 39 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			return;
#line 523 "webmedia-now-playing.c"
		}
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp40_ = g_regex_new ("(http|https)://www.zippcast.com/video/[&=_\\-A-Za-z0-9.\\|]+", 0, 0, &_inner_error_);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		zippcast = _tmp40_;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (coub);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (dailymotion);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (vimeo);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 541 "webmedia-now-playing.c"
				goto __catch0_g_regex_error;
			}
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (coub);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (dailymotion);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (vimeo);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_regex_unref0 (youtube);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_g_object_unref0 (browser);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_clear_error (&_inner_error_);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			return;
#line 560 "webmedia-now-playing.c"
		}
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		website = NULL;
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp45_ = self->priv->_web_media_uri;
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp46_ = string_contains (_tmp45_, "youtube");
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (_tmp46_) {
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp44_ = TRUE;
#line 572 "webmedia-now-playing.c"
		} else {
			const gchar* _tmp47_;
			gboolean _tmp48_;
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp47_ = self->priv->_web_media_uri;
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp48_ = string_contains (_tmp47_, "vimeo");
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp44_ = _tmp48_;
#line 582 "webmedia-now-playing.c"
		}
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (_tmp44_) {
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp43_ = TRUE;
#line 588 "webmedia-now-playing.c"
		} else {
			const gchar* _tmp49_;
			gboolean _tmp50_;
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp49_ = self->priv->_web_media_uri;
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp50_ = string_contains (_tmp49_, "dailymotion");
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp43_ = _tmp50_;
#line 598 "webmedia-now-playing.c"
		}
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (_tmp43_) {
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp42_ = TRUE;
#line 604 "webmedia-now-playing.c"
		} else {
			const gchar* _tmp51_;
			gboolean _tmp52_;
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp51_ = self->priv->_web_media_uri;
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp52_ = string_contains (_tmp51_, "coub");
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp42_ = _tmp52_;
#line 614 "webmedia-now-playing.c"
		}
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (_tmp42_) {
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp41_ = TRUE;
#line 620 "webmedia-now-playing.c"
		} else {
			const gchar* _tmp53_;
			gboolean _tmp54_;
#line 45 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp53_ = self->priv->_web_media_uri;
#line 45 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp54_ = string_contains (_tmp53_, "zippcast");
#line 45 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp41_ = _tmp54_;
#line 630 "webmedia-now-playing.c"
		}
#line 43 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (_tmp41_) {
#line 634 "webmedia-now-playing.c"
			GRegex* _tmp55_;
			const gchar* _tmp56_;
			gboolean _tmp57_;
			const gchar* _tmp75_;
#line 46 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp55_ = youtube;
#line 46 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp56_ = self->priv->_web_media_uri;
#line 46 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp57_ = g_regex_match (_tmp55_, _tmp56_, 0, NULL);
#line 46 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_tmp57_) {
#line 647 "webmedia-now-playing.c"
				gchar* _tmp58_;
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp58_ = g_strdup ("Youtube");
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_g_free0 (website);
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				website = _tmp58_;
#line 655 "webmedia-now-playing.c"
			} else {
				GRegex* _tmp59_;
				const gchar* _tmp60_;
				gboolean _tmp61_;
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp59_ = vimeo;
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp60_ = self->priv->_web_media_uri;
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp61_ = g_regex_match (_tmp59_, _tmp60_, 0, NULL);
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				if (_tmp61_) {
#line 668 "webmedia-now-playing.c"
					gchar* _tmp62_;
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
					_tmp62_ = g_strdup ("Vimeo");
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
					_g_free0 (website);
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
					website = _tmp62_;
#line 676 "webmedia-now-playing.c"
				} else {
					GRegex* _tmp63_;
					const gchar* _tmp64_;
					gboolean _tmp65_;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
					_tmp63_ = dailymotion;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
					_tmp64_ = self->priv->_web_media_uri;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
					_tmp65_ = g_regex_match (_tmp63_, _tmp64_, 0, NULL);
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
					if (_tmp65_) {
#line 689 "webmedia-now-playing.c"
						gchar* _tmp66_;
#line 51 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
						_tmp66_ = g_strdup ("Dailymotion");
#line 51 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
						_g_free0 (website);
#line 51 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
						website = _tmp66_;
#line 697 "webmedia-now-playing.c"
					} else {
						GRegex* _tmp67_;
						const gchar* _tmp68_;
						gboolean _tmp69_;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
						_tmp67_ = coub;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
						_tmp68_ = self->priv->_web_media_uri;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
						_tmp69_ = g_regex_match (_tmp67_, _tmp68_, 0, NULL);
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
						if (_tmp69_) {
#line 710 "webmedia-now-playing.c"
							gchar* _tmp70_;
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
							_tmp70_ = g_strdup ("Coub");
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
							_g_free0 (website);
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
							website = _tmp70_;
#line 718 "webmedia-now-playing.c"
						} else {
							GRegex* _tmp71_;
							const gchar* _tmp72_;
							gboolean _tmp73_;
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
							_tmp71_ = zippcast;
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
							_tmp72_ = self->priv->_web_media_uri;
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
							_tmp73_ = g_regex_match (_tmp71_, _tmp72_, 0, NULL);
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
							if (_tmp73_) {
#line 731 "webmedia-now-playing.c"
								gchar* _tmp74_;
#line 55 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
								_tmp74_ = g_strdup ("ZippCast");
#line 55 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
								_g_free0 (website);
#line 55 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
								website = _tmp74_;
#line 739 "webmedia-now-playing.c"
							}
						}
					}
				}
			}
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			_tmp75_ = website;
#line 57 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_tmp75_ != NULL) {
#line 749 "webmedia-now-playing.c"
				WebMediaDbusService* _tmp76_;
				const gchar* _tmp77_;
				WebMediaWebMediaNotify* _tmp78_;
				const gchar* _tmp79_;
				WebMediaWebMediaNotify* _tmp80_;
				const gchar* _tmp81_;
				WebMediaDbusService* _tmp82_;
				const gchar* _tmp83_;
				WebMediaWebMediaNotify* _tmp84_;
#line 58 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp76_ = self->priv->_dbus_service;
#line 58 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp77_ = self->priv->_web_media_title;
#line 58 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				web_media_dbus_service_set_video_title (_tmp76_, _tmp77_);
#line 59 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp78_ = self->priv->_web_media_notify;
#line 59 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp79_ = website;
#line 59 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				web_media_web_media_notify_set_notify_media (_tmp78_, _tmp79_);
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp80_ = self->priv->_web_media_notify;
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp81_ = self->priv->_web_media_title;
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				web_media_web_media_notify_set_notify_video_title (_tmp80_, _tmp81_);
#line 61 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp82_ = self->priv->_dbus_service;
#line 61 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp83_ = self->priv->_web_media_uri;
#line 61 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				web_media_dbus_service_set_video_uri (_tmp82_, _tmp83_);
#line 62 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp84_ = self->priv->_web_media_notify;
#line 62 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				web_media_web_media_notify_show_notify (_tmp84_);
#line 787 "webmedia-now-playing.c"
			}
		}
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_free0 (website);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_regex_unref0 (zippcast);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_regex_unref0 (coub);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_regex_unref0 (dailymotion);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_regex_unref0 (vimeo);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_regex_unref0 (youtube);
#line 802 "webmedia-now-playing.c"
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		GError* e = NULL;
		GError* _tmp85_;
		const gchar* _tmp86_;
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		e = _inner_error_;
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_inner_error_ = NULL;
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp85_ = e;
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp86_ = _tmp85_->message;
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_warning ("webmedia-now-playing.vala:66: %s", _tmp86_);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_error_free0 (e);
#line 822 "webmedia-now-playing.c"
	}
	__finally0:
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_object_unref0 (browser);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_clear_error (&_inner_error_);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		return;
#line 835 "webmedia-now-playing.c"
	}
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (browser);
#line 839 "webmedia-now-playing.c"
}


static void _web_media_manager_youtube_validation_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 71 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_youtube_validation ((WebMediaManager*) self, _sender, pspec);
#line 846 "webmedia-now-playing.c"
}


static void web_media_manager_browser_added (WebMediaManager* self, MidoriBrowser* browser) {
	MidoriBrowser* _tmp0_;
#line 70 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 70 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (browser != NULL);
#line 71 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = browser;
#line 71 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_signal_connect_object ((GObject*) _tmp0_, "notify::title", (GCallback) _web_media_manager_youtube_validation_g_object_notify, self, 0);
#line 860 "webmedia-now-playing.c"
}


static void _web_media_manager_browser_added_midori_app_add_browser (MidoriApp* _sender, MidoriBrowser* browser, gpointer self) {
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_browser_added ((WebMediaManager*) self, browser);
#line 867 "webmedia-now-playing.c"
}


static void web_media_manager_activated (WebMediaManager* self, MidoriApp* app) {
	WebMediaDbusService* _tmp0_;
	WebMediaDbusService* _tmp1_;
	MidoriApp* _tmp2_;
	WebMediaWebMediaNotify* _tmp3_;
	WebMediaWebMediaNotify* _tmp4_;
	MidoriApp* _tmp5_;
	GList* _tmp6_;
	MidoriApp* _tmp8_;
	WebMediaDbusService* _tmp9_;
#line 74 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 74 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (app != NULL);
#line 75 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = web_media_dbus_service_new ();
#line 75 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = _tmp0_;
#line 75 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_set_dbus_service (self, _tmp1_);
#line 75 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (_tmp1_);
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp2_ = app;
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp3_ = web_media_web_media_notify_new (_tmp2_);
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp4_ = _tmp3_;
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_set_web_media_notify (self, _tmp4_);
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (_tmp4_);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp5_ = app;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp6_ = midori_app_get_browsers (_tmp5_);
#line 907 "webmedia-now-playing.c"
	{
		GList* browser_collection = NULL;
		GList* browser_it = NULL;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		browser_collection = _tmp6_;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		for (browser_it = browser_collection; browser_it != NULL; browser_it = browser_it->next) {
#line 915 "webmedia-now-playing.c"
			MidoriBrowser* browser = NULL;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			browser = (MidoriBrowser*) browser_it->data;
#line 919 "webmedia-now-playing.c"
			{
				MidoriBrowser* _tmp7_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp7_ = browser;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				web_media_manager_browser_added (self, _tmp7_);
#line 926 "webmedia-now-playing.c"
			}
		}
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_list_free0 (browser_collection);
#line 931 "webmedia-now-playing.c"
	}
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp8_ = app;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_signal_connect_object (_tmp8_, "add-browser", (GCallback) _web_media_manager_browser_added_midori_app_add_browser, self, 0);
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp9_ = self->priv->_dbus_service;
#line 80 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_register_service (_tmp9_);
#line 941 "webmedia-now-playing.c"
}


static void web_media_manager_deactivated (WebMediaManager* self) {
	MidoriApp* app = NULL;
	MidoriApp* _tmp0_;
	MidoriApp* _tmp1_;
	MidoriApp* _tmp2_;
	guint _tmp3_;
	WebMediaDbusService* _tmp4_;
	MidoriApp* _tmp5_;
	GList* _tmp6_;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 84 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = midori_extension_get_app ((MidoriExtension*) self);
#line 84 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 84 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	app = _tmp1_;
#line 85 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp2_ = app;
#line 85 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_signal_parse_name ("add-browser", MIDORI_TYPE_APP, &_tmp3_, NULL, FALSE);
#line 85 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _web_media_manager_browser_added_midori_app_add_browser, self);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp4_ = self->priv->_dbus_service;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_unregister_service (_tmp4_);
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp5_ = app;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp6_ = midori_app_get_browsers (_tmp5_);
#line 976 "webmedia-now-playing.c"
	{
		GList* browser_collection = NULL;
		GList* browser_it = NULL;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		browser_collection = _tmp6_;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		for (browser_it = browser_collection; browser_it != NULL; browser_it = browser_it->next) {
#line 984 "webmedia-now-playing.c"
			MidoriBrowser* browser = NULL;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			browser = (MidoriBrowser*) browser_it->data;
#line 988 "webmedia-now-playing.c"
			{
				MidoriBrowser* _tmp7_;
				guint _tmp8_;
				GQuark _tmp9_;
#line 88 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				_tmp7_ = browser;
#line 88 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				g_signal_parse_name ("notify::title", G_TYPE_OBJECT, &_tmp8_, &_tmp9_, TRUE);
#line 88 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
				g_signal_handlers_disconnect_matched ((GObject*) _tmp7_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DETAIL | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, _tmp9_, NULL, (GCallback) _web_media_manager_youtube_validation_g_object_notify, self);
#line 999 "webmedia-now-playing.c"
			}
		}
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_list_free0 (browser_collection);
#line 1004 "webmedia-now-playing.c"
	}
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (app);
#line 1008 "webmedia-now-playing.c"
}


static WebMediaDbusService* web_media_manager_get_dbus_service (WebMediaManager* self) {
	WebMediaDbusService* result;
	WebMediaDbusService* _tmp0_;
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_dbus_service;
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1023 "webmedia-now-playing.c"
}


static void web_media_manager_set_dbus_service (WebMediaManager* self, WebMediaDbusService* value) {
	WebMediaDbusService* _tmp0_;
	WebMediaDbusService* _tmp1_;
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = value;
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (self->priv->_dbus_service);
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv->_dbus_service = _tmp1_;
#line 1040 "webmedia-now-playing.c"
}


static WebMediaWebMediaNotify* web_media_manager_get_web_media_notify (WebMediaManager* self) {
	WebMediaWebMediaNotify* result;
	WebMediaWebMediaNotify* _tmp0_;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_web_media_notify;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1055 "webmedia-now-playing.c"
}


static void web_media_manager_set_web_media_notify (WebMediaManager* self, WebMediaWebMediaNotify* value) {
	WebMediaWebMediaNotify* _tmp0_;
	WebMediaWebMediaNotify* _tmp1_;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = value;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (self->priv->_web_media_notify);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv->_web_media_notify = _tmp1_;
#line 1072 "webmedia-now-playing.c"
}


static const gchar* web_media_manager_get_web_media_uri (WebMediaManager* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_web_media_uri;
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1087 "webmedia-now-playing.c"
}


static void web_media_manager_set_web_media_uri (WebMediaManager* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = value;
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_web_media_uri);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv->_web_media_uri = _tmp1_;
#line 1104 "webmedia-now-playing.c"
}


static const gchar* web_media_manager_get_web_media_title (WebMediaManager* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_web_media_title;
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1119 "webmedia-now-playing.c"
}


static void web_media_manager_set_web_media_title (WebMediaManager* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = value;
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_web_media_title);
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv->_web_media_title = _tmp1_;
#line 1136 "webmedia-now-playing.c"
}


static void web_media_manager_class_init (WebMediaManagerClass * klass) {
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_manager_parent_class = g_type_class_peek_parent (klass);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_type_class_add_private (klass, sizeof (WebMediaManagerPrivate));
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_web_media_manager_get_property;
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_web_media_manager_set_property;
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->finalize = web_media_manager_finalize;
#line 1151 "webmedia-now-playing.c"
}


static void web_media_manager_instance_init (WebMediaManager * self) {
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv = WEB_MEDIA_MANAGER_GET_PRIVATE (self);
#line 1158 "webmedia-now-playing.c"
}


static void web_media_manager_finalize (GObject * obj) {
	WebMediaManager * self;
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, WEB_MEDIA_TYPE_MANAGER, WebMediaManager);
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (self->priv->_dbus_service);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (self->priv->_web_media_notify);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_web_media_uri);
#line 18 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_web_media_title);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (web_media_manager_parent_class)->finalize (obj);
#line 1176 "webmedia-now-playing.c"
}


GType web_media_manager_get_type (void) {
	static volatile gsize web_media_manager_type_id__volatile = 0;
	if (g_once_init_enter (&web_media_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (WebMediaManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) web_media_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WebMediaManager), 0, (GInstanceInitFunc) web_media_manager_instance_init, NULL };
		GType web_media_manager_type_id;
		web_media_manager_type_id = g_type_register_static (MIDORI_TYPE_EXTENSION, "WebMediaManager", &g_define_type_info, 0);
		g_once_init_leave (&web_media_manager_type_id__volatile, web_media_manager_type_id);
	}
	return web_media_manager_type_id__volatile;
}


static void _vala_web_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	WebMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WEB_MEDIA_TYPE_MANAGER, WebMediaManager);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	switch (property_id) {
#line 1197 "webmedia-now-playing.c"
		default:
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 1203 "webmedia-now-playing.c"
	}
}


static void _vala_web_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	WebMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WEB_MEDIA_TYPE_MANAGER, WebMediaManager);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	switch (property_id) {
#line 1213 "webmedia-now-playing.c"
		default:
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 1219 "webmedia-now-playing.c"
	}
}


WebMediaDbusService* web_media_dbus_service_construct (GType object_type) {
	WebMediaDbusService * self = NULL;
#line 100 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self = (WebMediaDbusService*) g_object_new (object_type, NULL);
#line 101 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_dbus_empty (self);
#line 100 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return self;
#line 1232 "webmedia-now-playing.c"
}


WebMediaDbusService* web_media_dbus_service_new (void) {
#line 100 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return web_media_dbus_service_construct (WEB_MEDIA_TYPE_DBUS_SERVICE);
#line 1239 "webmedia-now-playing.c"
}


void web_media_dbus_service_dbus_empty (WebMediaDbusService* self) {
#line 104 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 105 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_set_video_title (self, NULL);
#line 106 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_set_video_uri (self, NULL);
#line 1250 "webmedia-now-playing.c"
}


static void _web_media_dbus_service_on_bus_aquired_gbus_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self) {
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_on_bus_aquired ((WebMediaDbusService*) self, connection);
#line 1257 "webmedia-now-playing.c"
}


static void __lambda4_ (WebMediaDbusService* self) {
}


static void ___lambda4__gbus_name_acquired_callback (GDBusConnection* connection, const gchar* name, gpointer self) {
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	__lambda4_ ((WebMediaDbusService*) self);
#line 1268 "webmedia-now-playing.c"
}


static void __lambda5_ (WebMediaDbusService* self) {
	FILE* _tmp0_;
#line 113 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = stderr;
#line 113 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	fprintf (_tmp0_, "Could not acquire name\n");
#line 1278 "webmedia-now-playing.c"
}


static void ___lambda5__gbus_name_lost_callback (GDBusConnection* connection, const gchar* name, gpointer self) {
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	__lambda5_ ((WebMediaDbusService*) self);
#line 1285 "webmedia-now-playing.c"
}


void web_media_dbus_service_register_service (WebMediaDbusService* self) {
	guint _tmp0_;
#line 109 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = g_bus_own_name_with_closures (G_BUS_TYPE_SESSION, "org.midori.mediaHerald", G_BUS_NAME_OWNER_FLAGS_NONE, (GClosure*) ((_web_media_dbus_service_on_bus_aquired_gbus_acquired_callback == NULL) ? NULL : g_cclosure_new ((GCallback) _web_media_dbus_service_on_bus_aquired_gbus_acquired_callback, g_object_ref (self), (GClosureNotify) g_object_unref)), (GClosure*) ((___lambda4__gbus_name_acquired_callback == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda4__gbus_name_acquired_callback, g_object_ref (self), (GClosureNotify) g_object_unref)), (GClosure*) ((___lambda5__gbus_name_lost_callback == NULL) ? NULL : g_cclosure_new ((GCallback) ___lambda5__gbus_name_lost_callback, g_object_ref (self), (GClosureNotify) g_object_unref)));
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_set_own_name_id (self, _tmp0_);
#line 1297 "webmedia-now-playing.c"
}


void web_media_dbus_service_unregister_service (WebMediaDbusService* self) {
	guint _tmp0_;
	GDBusConnection* _tmp1_;
	guint _tmp2_;
#line 116 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_own_name_id;
#line 117 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_bus_unown_name (_tmp0_);
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = self->priv->_dbus_service_connection;
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp2_ = self->priv->_service;
#line 118 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_dbus_connection_unregister_object (_tmp1_, _tmp2_);
#line 1317 "webmedia-now-playing.c"
}


static void web_media_dbus_service_on_bus_aquired (WebMediaDbusService* self, GDBusConnection* connection) {
	GError * _inner_error_ = NULL;
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (connection != NULL);
#line 1327 "webmedia-now-playing.c"
	{
		GDBusConnection* _tmp0_;
		guint _tmp1_ = 0U;
		GDBusConnection* _tmp2_;
		guint _tmp3_;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp0_ = connection;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		web_media_dbus_service_set_dbus_service_connection (self, _tmp0_);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp2_ = connection;
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp3_ = web_media_dbus_service_register_object (self, _tmp2_, "/org/midori/mediaHerald", &_inner_error_);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp1_ = _tmp3_;
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			if (_inner_error_->domain == G_IO_ERROR) {
#line 1347 "webmedia-now-playing.c"
				goto __catch1_g_io_error;
			}
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			g_clear_error (&_inner_error_);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
			return;
#line 1356 "webmedia-now-playing.c"
		}
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		web_media_dbus_service_set_service (self, _tmp1_);
#line 1360 "webmedia-now-playing.c"
	}
	goto __finally1;
	__catch1_g_io_error:
	{
		GError* e = NULL;
		FILE* _tmp4_;
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		e = _inner_error_;
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_inner_error_ = NULL;
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp4_ = stderr;
#line 126 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		fprintf (_tmp4_, "Could not register service\n");
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_error_free0 (e);
#line 1377 "webmedia-now-playing.c"
	}
	__finally1:
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_clear_error (&_inner_error_);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		return;
#line 1388 "webmedia-now-playing.c"
	}
}


static guint web_media_dbus_service_get_service (WebMediaDbusService* self) {
	guint result;
	guint _tmp0_;
#line 94 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 94 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_service;
#line 94 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 94 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1404 "webmedia-now-playing.c"
}


static void web_media_dbus_service_set_service (WebMediaDbusService* self, guint value) {
	guint _tmp0_;
#line 94 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 94 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = value;
#line 94 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv->_service = _tmp0_;
#line 1416 "webmedia-now-playing.c"
}


static guint web_media_dbus_service_get_own_name_id (WebMediaDbusService* self) {
	guint result;
	guint _tmp0_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_own_name_id;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1431 "webmedia-now-playing.c"
}


static void web_media_dbus_service_set_own_name_id (WebMediaDbusService* self, guint value) {
	guint _tmp0_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = value;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv->_own_name_id = _tmp0_;
#line 1443 "webmedia-now-playing.c"
}


static GDBusConnection* web_media_dbus_service_get_dbus_service_connection (WebMediaDbusService* self) {
	GDBusConnection* result;
	GDBusConnection* _tmp0_;
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_dbus_service_connection;
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1458 "webmedia-now-playing.c"
}


static void web_media_dbus_service_set_dbus_service_connection (WebMediaDbusService* self, GDBusConnection* value) {
	GDBusConnection* _tmp0_;
	GDBusConnection* _tmp1_;
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = value;
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (self->priv->_dbus_service_connection);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv->_dbus_service_connection = _tmp1_;
#line 1475 "webmedia-now-playing.c"
}


const gchar* web_media_dbus_service_get_video_title (WebMediaDbusService* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_video_title;
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1490 "webmedia-now-playing.c"
}


void web_media_dbus_service_set_video_title (WebMediaDbusService* self, const gchar* value) {
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (g_strcmp0 (value, web_media_dbus_service_get_video_title (self)) != 0) {
#line 1499 "webmedia-now-playing.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp0_ = value;
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_free0 (self->priv->_video_title);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		self->priv->_video_title = _tmp1_;
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_object_notify_by_pspec ((GObject *) self, web_media_dbus_service_properties[WEB_MEDIA_DBUS_SERVICE_VIDEO_TITLE_PROPERTY]);
#line 1512 "webmedia-now-playing.c"
	}
}


const gchar* web_media_dbus_service_get_video_uri (WebMediaDbusService* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_video_uri;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1528 "webmedia-now-playing.c"
}


void web_media_dbus_service_set_video_uri (WebMediaDbusService* self, const gchar* value) {
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (g_strcmp0 (value, web_media_dbus_service_get_video_uri (self)) != 0) {
#line 1537 "webmedia-now-playing.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp0_ = value;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_free0 (self->priv->_video_uri);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		self->priv->_video_uri = _tmp1_;
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_object_notify_by_pspec ((GObject *) self, web_media_dbus_service_properties[WEB_MEDIA_DBUS_SERVICE_VIDEO_URI_PROPERTY]);
#line 1550 "webmedia-now-playing.c"
	}
}


static void web_media_dbus_service_class_init (WebMediaDbusServiceClass * klass) {
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_dbus_service_parent_class = g_type_class_peek_parent (klass);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_type_class_add_private (klass, sizeof (WebMediaDbusServicePrivate));
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_web_media_dbus_service_get_property;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_web_media_dbus_service_set_property;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->finalize = web_media_dbus_service_finalize;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), WEB_MEDIA_DBUS_SERVICE_VIDEO_TITLE_PROPERTY, web_media_dbus_service_properties[WEB_MEDIA_DBUS_SERVICE_VIDEO_TITLE_PROPERTY] = g_param_spec_string ("video-title", "video-title", "video-title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), WEB_MEDIA_DBUS_SERVICE_VIDEO_URI_PROPERTY, web_media_dbus_service_properties[WEB_MEDIA_DBUS_SERVICE_VIDEO_URI_PROPERTY] = g_param_spec_string ("video-uri", "video-uri", "video-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1570 "webmedia-now-playing.c"
}


static void web_media_dbus_service_instance_init (WebMediaDbusService * self) {
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv = WEB_MEDIA_DBUS_SERVICE_GET_PRIVATE (self);
#line 1577 "webmedia-now-playing.c"
}


static void web_media_dbus_service_finalize (GObject * obj) {
	WebMediaDbusService * self;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, WEB_MEDIA_TYPE_DBUS_SERVICE, WebMediaDbusService);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (self->priv->_dbus_service_connection);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_video_title);
#line 98 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_video_uri);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (web_media_dbus_service_parent_class)->finalize (obj);
#line 1593 "webmedia-now-playing.c"
}


GType web_media_dbus_service_get_type (void) {
	static volatile gsize web_media_dbus_service_type_id__volatile = 0;
	if (g_once_init_enter (&web_media_dbus_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (WebMediaDbusServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) web_media_dbus_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WebMediaDbusService), 0, (GInstanceInitFunc) web_media_dbus_service_instance_init, NULL };
		GType web_media_dbus_service_type_id;
		web_media_dbus_service_type_id = g_type_register_static (G_TYPE_OBJECT, "WebMediaDbusService", &g_define_type_info, 0);
		g_type_set_qdata (web_media_dbus_service_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) web_media_dbus_service_register_object);
		g_once_init_leave (&web_media_dbus_service_type_id__volatile, web_media_dbus_service_type_id);
	}
	return web_media_dbus_service_type_id__volatile;
}


static void _vala_web_media_dbus_service_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	WebMediaDbusService * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WEB_MEDIA_TYPE_DBUS_SERVICE, WebMediaDbusService);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	switch (property_id) {
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_DBUS_SERVICE_VIDEO_TITLE_PROPERTY:
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_value_set_string (value, web_media_dbus_service_get_video_title (self));
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_DBUS_SERVICE_VIDEO_URI_PROPERTY:
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_value_set_string (value, web_media_dbus_service_get_video_uri (self));
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 1627 "webmedia-now-playing.c"
		default:
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 1633 "webmedia-now-playing.c"
	}
}


static void _vala_web_media_dbus_service_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	WebMediaDbusService * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WEB_MEDIA_TYPE_DBUS_SERVICE, WebMediaDbusService);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	switch (property_id) {
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_DBUS_SERVICE_VIDEO_TITLE_PROPERTY:
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		web_media_dbus_service_set_video_title (self, g_value_get_string (value));
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_DBUS_SERVICE_VIDEO_URI_PROPERTY:
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		web_media_dbus_service_set_video_uri (self, g_value_get_string (value));
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 1655 "webmedia-now-playing.c"
		default:
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 1661 "webmedia-now-playing.c"
	}
}


static void _dbus_web_media_dbus_service_dbus_empty (WebMediaDbusService* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	web_media_dbus_service_dbus_empty (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_web_media_dbus_service_register_service (WebMediaDbusService* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	web_media_dbus_service_register_service (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void _dbus_web_media_dbus_service_unregister_service (WebMediaDbusService* self, GVariant* _parameters_, GDBusMethodInvocation* invocation) {
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	web_media_dbus_service_unregister_service (self);
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}


static void web_media_dbus_service_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "DbusEmpty") == 0) {
		_dbus_web_media_dbus_service_dbus_empty (object, parameters, invocation);
	} else if (strcmp (method_name, "RegisterService") == 0) {
		_dbus_web_media_dbus_service_register_service (object, parameters, invocation);
	} else if (strcmp (method_name, "UnregisterService") == 0) {
		_dbus_web_media_dbus_service_unregister_service (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}


static GVariant* _dbus_web_media_dbus_service_get_video_title (WebMediaDbusService* self) {
	const gchar* result;
	GVariant* _reply;
	result = web_media_dbus_service_get_video_title (self);
	_reply = g_variant_new_string (result);
	return _reply;
}


static GVariant* _dbus_web_media_dbus_service_get_video_uri (WebMediaDbusService* self) {
	const gchar* result;
	GVariant* _reply;
	result = web_media_dbus_service_get_video_uri (self);
	_reply = g_variant_new_string (result);
	return _reply;
}


static GVariant* web_media_dbus_service_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "VideoTitle") == 0) {
		return _dbus_web_media_dbus_service_get_video_title (object);
	} else if (strcmp (property_name, "VideoUri") == 0) {
		return _dbus_web_media_dbus_service_get_video_uri (object);
	}
	return NULL;
}


static void _dbus_web_media_dbus_service_set_video_title (WebMediaDbusService* self, GVariant* _value) {
	gchar* value = NULL;
	value = g_variant_dup_string (_value, NULL);
	web_media_dbus_service_set_video_title (self, value);
	_g_free0 (value);
}


static void _dbus_web_media_dbus_service_set_video_uri (WebMediaDbusService* self, GVariant* _value) {
	gchar* value = NULL;
	value = g_variant_dup_string (_value, NULL);
	web_media_dbus_service_set_video_uri (self, value);
	_g_free0 (value);
}


static gboolean web_media_dbus_service_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "VideoTitle") == 0) {
		_dbus_web_media_dbus_service_set_video_title (object, value);
		return TRUE;
	} else if (strcmp (property_name, "VideoUri") == 0) {
		_dbus_web_media_dbus_service_set_video_uri (object, value);
		return TRUE;
	}
	return FALSE;
}


guint web_media_dbus_service_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_web_media_dbus_service_dbus_interface_info), &_web_media_dbus_service_dbus_interface_vtable, data, _web_media_dbus_service_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}


static void _web_media_dbus_service_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}


WebMediaWebMediaNotify* web_media_web_media_notify_construct (GType object_type, MidoriApp* app) {
	WebMediaWebMediaNotify * self = NULL;
	MidoriApp* _tmp0_;
#line 136 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (app != NULL, NULL);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = app;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self = (WebMediaWebMediaNotify*) g_object_new (object_type, "app", _tmp0_, NULL);
#line 136 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return self;
#line 1837 "webmedia-now-playing.c"
}


WebMediaWebMediaNotify* web_media_web_media_notify_new (MidoriApp* app) {
#line 136 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return web_media_web_media_notify_construct (WEB_MEDIA_TYPE_WEB_MEDIA_NOTIFY, app);
#line 1844 "webmedia-now-playing.c"
}


void web_media_web_media_notify_show_notify (WebMediaWebMediaNotify* self) {
	MidoriApp* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_app;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp1_ = self->priv->_notify_media;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp2_ = g_strconcat ("Midori is playing in ", _tmp1_, NULL);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp3_ = _tmp2_;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp4_ = self->priv->_notify_video_title;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	midori_app_send_notification (_tmp0_, _tmp3_, _tmp4_);
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (_tmp3_);
#line 1870 "webmedia-now-playing.c"
}


MidoriApp* web_media_web_media_notify_get_app (WebMediaWebMediaNotify* self) {
	MidoriApp* result;
	MidoriApp* _tmp0_;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_app;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1885 "webmedia-now-playing.c"
}


void web_media_web_media_notify_set_app (WebMediaWebMediaNotify* self, MidoriApp* value) {
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (web_media_web_media_notify_get_app (self) != value) {
#line 1894 "webmedia-now-playing.c"
		MidoriApp* _tmp0_;
		MidoriApp* _tmp1_;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp0_ = value;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_object_unref0 (self->priv->_app);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		self->priv->_app = _tmp1_;
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_object_notify_by_pspec ((GObject *) self, web_media_web_media_notify_properties[WEB_MEDIA_WEB_MEDIA_NOTIFY_APP_PROPERTY]);
#line 1907 "webmedia-now-playing.c"
	}
}


const gchar* web_media_web_media_notify_get_notify_video_title (WebMediaWebMediaNotify* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_notify_video_title;
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1923 "webmedia-now-playing.c"
}


void web_media_web_media_notify_set_notify_video_title (WebMediaWebMediaNotify* self, const gchar* value) {
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (g_strcmp0 (value, web_media_web_media_notify_get_notify_video_title (self)) != 0) {
#line 1932 "webmedia-now-playing.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp0_ = value;
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_free0 (self->priv->_notify_video_title);
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		self->priv->_notify_video_title = _tmp1_;
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_object_notify_by_pspec ((GObject *) self, web_media_web_media_notify_properties[WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_VIDEO_TITLE_PROPERTY]);
#line 1945 "webmedia-now-playing.c"
	}
}


const gchar* web_media_web_media_notify_get_notify_media (WebMediaWebMediaNotify* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = self->priv->_notify_media;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = _tmp0_;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 1961 "webmedia-now-playing.c"
}


void web_media_web_media_notify_set_notify_media (WebMediaWebMediaNotify* self, const gchar* value) {
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_return_if_fail (self != NULL);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	if (g_strcmp0 (value, web_media_web_media_notify_get_notify_media (self)) != 0) {
#line 1970 "webmedia-now-playing.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp0_ = value;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		_g_free0 (self->priv->_notify_media);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		self->priv->_notify_media = _tmp1_;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_object_notify_by_pspec ((GObject *) self, web_media_web_media_notify_properties[WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_MEDIA_PROPERTY]);
#line 1983 "webmedia-now-playing.c"
	}
}


static void web_media_web_media_notify_class_init (WebMediaWebMediaNotifyClass * klass) {
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	web_media_web_media_notify_parent_class = g_type_class_peek_parent (klass);
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_type_class_add_private (klass, sizeof (WebMediaWebMediaNotifyPrivate));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_web_media_web_media_notify_get_property;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_web_media_web_media_notify_set_property;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (klass)->finalize = web_media_web_media_notify_finalize;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), WEB_MEDIA_WEB_MEDIA_NOTIFY_APP_PROPERTY, web_media_web_media_notify_properties[WEB_MEDIA_WEB_MEDIA_NOTIFY_APP_PROPERTY] = g_param_spec_object ("app", "app", "app", MIDORI_TYPE_APP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_VIDEO_TITLE_PROPERTY, web_media_web_media_notify_properties[WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_VIDEO_TITLE_PROPERTY] = g_param_spec_string ("notify-video-title", "notify-video-title", "notify-video-title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_MEDIA_PROPERTY, web_media_web_media_notify_properties[WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_MEDIA_PROPERTY] = g_param_spec_string ("notify-media", "notify-media", "notify-media", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2005 "webmedia-now-playing.c"
}


static void web_media_web_media_notify_instance_init (WebMediaWebMediaNotify * self) {
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self->priv = WEB_MEDIA_WEB_MEDIA_NOTIFY_GET_PRIVATE (self);
#line 2012 "webmedia-now-playing.c"
}


static void web_media_web_media_notify_finalize (GObject * obj) {
	WebMediaWebMediaNotify * self;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, WEB_MEDIA_TYPE_WEB_MEDIA_NOTIFY, WebMediaWebMediaNotify);
#line 132 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_object_unref0 (self->priv->_app);
#line 133 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_notify_video_title);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_g_free0 (self->priv->_notify_media);
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	G_OBJECT_CLASS (web_media_web_media_notify_parent_class)->finalize (obj);
#line 2028 "webmedia-now-playing.c"
}


GType web_media_web_media_notify_get_type (void) {
	static volatile gsize web_media_web_media_notify_type_id__volatile = 0;
	if (g_once_init_enter (&web_media_web_media_notify_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (WebMediaWebMediaNotifyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) web_media_web_media_notify_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WebMediaWebMediaNotify), 0, (GInstanceInitFunc) web_media_web_media_notify_instance_init, NULL };
		GType web_media_web_media_notify_type_id;
		web_media_web_media_notify_type_id = g_type_register_static (G_TYPE_OBJECT, "WebMediaWebMediaNotify", &g_define_type_info, 0);
		g_once_init_leave (&web_media_web_media_notify_type_id__volatile, web_media_web_media_notify_type_id);
	}
	return web_media_web_media_notify_type_id__volatile;
}


static void _vala_web_media_web_media_notify_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	WebMediaWebMediaNotify * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WEB_MEDIA_TYPE_WEB_MEDIA_NOTIFY, WebMediaWebMediaNotify);
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	switch (property_id) {
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_WEB_MEDIA_NOTIFY_APP_PROPERTY:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_value_set_object (value, web_media_web_media_notify_get_app (self));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_VIDEO_TITLE_PROPERTY:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_value_set_string (value, web_media_web_media_notify_get_notify_video_title (self));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_MEDIA_PROPERTY:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		g_value_set_string (value, web_media_web_media_notify_get_notify_media (self));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 2067 "webmedia-now-playing.c"
		default:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 2073 "webmedia-now-playing.c"
	}
}


static void _vala_web_media_web_media_notify_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	WebMediaWebMediaNotify * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WEB_MEDIA_TYPE_WEB_MEDIA_NOTIFY, WebMediaWebMediaNotify);
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	switch (property_id) {
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_WEB_MEDIA_NOTIFY_APP_PROPERTY:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		web_media_web_media_notify_set_app (self, g_value_get_object (value));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_VIDEO_TITLE_PROPERTY:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		web_media_web_media_notify_set_notify_video_title (self, g_value_get_string (value));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		case WEB_MEDIA_WEB_MEDIA_NOTIFY_NOTIFY_MEDIA_PROPERTY:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		web_media_web_media_notify_set_notify_media (self, g_value_get_string (value));
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 2101 "webmedia-now-playing.c"
		default:
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 131 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
		break;
#line 2107 "webmedia-now-playing.c"
	}
}


MidoriExtension* extension_init (void) {
	MidoriExtension* result = NULL;
	WebMediaManager* _tmp0_;
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	_tmp0_ = web_media_manager_new ();
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	result = (MidoriExtension*) _tmp0_;
#line 147 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/webmedia-now-playing.vala"
	return result;
#line 2121 "webmedia-now-playing.c"
}



